-- Define fragment shader code
local fragmentShaderCode = [[
    extern vec2 center;
    extern float radius;
    extern float glowStrength;

    vec4 effect(vec4 vertexColor, Image tex, vec2 texcoord, vec2 pixcoord) {
        // Calculate distance from the center of the circle
        float distance = length(center - pixcoord);
        
        // Calculate the ratio of the current distance to the radius
        float distanceRatio = distance / radius;
        
        // Calculate the red intensity based on the distance ratio
        float redIntensity = 1.0 - distanceRatio;
        
        // Apply glow strength
        redIntensity = clamp(redIntensity - glowStrength, 0.0, 1.0);
        
        // Output the color with red intensity modulated
        vec4 color = vec4(redIntensity, 0.0, 0.0, 1.0);
        
        return color;
    }
]]


function love.load()
    love.window.setTitle('game1_subjectToChange')
    love.window.setMode(1280, 720, {fullscreen=true})
    WINDOW_WIDTH = love.graphics.getWidth()
    WINDOW_HEIGHT = love.graphics.getHeight()

    -- Create shader object
    glow_shader = love.graphics.newShader(fragmentShaderCode)

    local glowStrength = 0.05
    local radius = 25

    -- Set shader uniforms
    glow_shader:send("radius", radius)
    glow_shader:send("glowStrength", glowStrength)

    -- Set initial position for the circle at the center horizontally
    x = love.graphics.getWidth() / 2
    Xelipse = love.graphics.getWidth() / 2

    factor = 1
    passed = 0
    faded = 0.25

    centerX = love.graphics.getWidth() / 2
    centerY =  love.graphics.getHeight() / 2
    centerX1 = love.graphics.getWidth() / 2
    ellipseWidth = 100

    FrontBlockX = WINDOW_WIDTH/2  + 400
    BackBlockX = WINDOW_WIDTH/2 
    phase = false
end

function love.update(dt)
    -- Update game state here
    passed = passed + dt
    ellipseWidth = ellipseWidth + math.sin(passed * 7 - 5)
    x =  x + math.sin( (passed * 7) -  5) 
    Xelipse = Xelipse -  math.sin( (passed * 7) -  5) 
    centerY = centerY + math.sin(passed * 8 - 2)
    centerX = centerX + math.sin((passed * 7) -  5) 
    centerX1 = centerX1 - math.sin((passed * 7) -  6) 

    if love.keyboard.isDown('escape') then
        love.event.quit()
    end    

        FrontBlockX = FrontBlockX - 15 * math.sin(passed * 2 - 100)



   

    if FrontBlockX <= WINDOW_WIDTH/2 -200 and phase == false then 
        phase = true

    elseif FrontBlockX >= WINDOW_WIDTH/2 +200 and phase == true then
        phase = false

    end



end

function love.draw() 
    local center = {centerX + 6, love.graphics.getHeight()/2}
    local radius = 100
    local glowStrength = 0.01

    love.graphics.push()
    love.graphics.setColor(0.1, 0, 0.1)
    love.graphics.rectangle("fill", 0, 0, WINDOW_WIDTH, WINDOW_HEIGHT)  
    love.graphics.pop()
    love.graphics.setColor(0.0,0.0,0.0)
    love.graphics.rectangle("fill",0,WINDOW_HEIGHT/2 + 30,WINDOW_WIDTH,20)
    love.graphics.setColor(0.0,0.0,0.0)
    love.graphics.ellipse("fill",WINDOW_WIDTH/2 - 30,WINDOW_HEIGHT/2 + 90,100,30,30)

    if phase == true then
        love.graphics.setColor(0.0,0.0,0.0)
        love.graphics.ellipse("fill",FrontBlockX-30,WINDOW_HEIGHT/2 + 75,70,10,30)
         
        love.graphics.setColor(0.0,0.15,0.0)
        love.graphics.circle("fill",FrontBlockX,WINDOW_HEIGHT/2 -20,100,30)


    end
    -- Set shader uniforms
    glow_shader:send("center", center)
    glow_shader:send("radius", radius)
    glow_shader:send("glowStrength", glowStrength)

    love.graphics.setShader(glow_shader) -- Set the shader before drawing
    love.graphics.setColor(0.5, 0.0, 0.0)
    love.graphics.circle("fill", x, WINDOW_HEIGHT / 2, 100, 100) -- Draw the circle
    love.graphics.setShader() -- Reset the shader

    if phase == false then
        love.graphics.setColor(0.0,0.0,0.0)
        love.graphics.ellipse("fill",FrontBlockX-30,WINDOW_HEIGHT/2 + 120,100,30,30)
        love.graphics.setColor(0.0,0.15,0.0)
        love.graphics.circle("fill",FrontBlockX,WINDOW_HEIGHT/2 -30,110,30)



    end
end
